<template>
  <div class="loginPage">
    <div class="loginForm">
      <p>数字教材阅读器</p>
      <el-form ref="ruleFormRef" :model="loginData" :rules="rules" label-width="80px">
        <el-form-item label="用户名：" prop="username">
          <el-input v-model="loginData.username"></el-input>
        </el-form-item>
        <el-form-item label="密码：" prop="password">
          <el-input type="password" v-model="loginData.password"></el-input>
        </el-form-item>
        <div class="btnBox">
          <el-button
            style="width: 120px"
            type="primary"
            @click="submitForm(ruleFormRef)"
            :loading="loading"
            >登 录</el-button
          >
        </div>
      </el-form>
    </div>
  </div>
</template>

<script setup lang="ts">
import { ref, reactive, inject } from 'vue'
import { useRoute, useRouter } from 'vue-router'
import { ElMessage } from 'element-plus'

const route = useRoute()
const router = useRouter()

const request = inject('request')

const ruleFormRef = ref()

const loginData = ref({
  username: '',
  password: ''
})

const rules = reactive({
  username: [{ required: true, message: '请填写用户名', trigger: 'blur' }],
  password: [{ required: true, message: '请填写密码', trigger: 'blur' }]
})

const loading = ref(false)

const submitForm = async (formEl) => {
  if (!formEl) return
  await formEl.validate((valid, fields) => {
    if (valid) {
      loading.value = true
      request({
        url: '/identity/api/LoginByPassword',
        method: 'post',
        data: {
          appRefCode: 'jingshieke',
          loginName: loginData.value.username,
          password: loginData.value.password,
          platform: 'string'
        }
      })
        .then((res) => {
          console.log(res)
          if (res.token != null) {
            localStorage.setItem('token', res.token)
            if (route.query.redirect) {
              router.push(route.query.redirect)
            } else {
              router.push('/')
            }
          } else if (res.data.isError) {
            ElMessage.error(res.data.errorDescription)
            loading.value = false
          }
        })
        .catch((errorMsg) => {
          ElMessage.error(errorMsg)
          loading.value = false
        })
    }
  })
}
</script>

<style lang="less">
.loginPage {
  width: 100%;
  height: 100%;
  position: relative;
  .loginForm {
    width: 400px;
    height: 300px;
    position: absolute;
    top: 50%;
    left: 50%;
    margin-top: -150px;
    margin-left: -200px;
    border: 1px solid #ccc;
    border-radius: 10px;
    padding: 20px;
    p {
      font-size: 20px;
      font-weight: bold;
      text-align: center;
      margin-bottom: 50px;
    }
    .btnBox {
      text-align: center;
      margin-top: 50px;
    }
  }
}
</style>
